From 7e68a6475160b0940ae426a6ce2a112f51f95fa9 Mon Sep 17 00:00:00 2001
From: Mark Spencer <markster@digium.com>
Date: Wed, 5 Jan 2000 08:20:35 +0000
Subject: [PATCH] Version 0.1.10 from FTP

git-svn-id: https://origsvn.digium.com/svn/asterisk/trunk@180 65c4cc65-6c06-0410-ace0-fbb531ad65f3
---
 codecs/lpc10/analys.c | 16 ++++++++--------
 codecs/lpc10/bsynz.c  | 16 ++++++++--------
 codecs/lpc10/chanwr.c |  8 ++++----
 codecs/lpc10/dcbias.c |  8 ++++----
 codecs/lpc10/decode.c | 16 ++++++++--------
 codecs/lpc10/deemp.c  |  8 ++++----
 codecs/lpc10/difmag.c |  8 ++++----
 codecs/lpc10/dyptrk.c | 12 ++++++------
 codecs/lpc10/encode.c | 16 ++++++++--------
 codecs/lpc10/energy.c |  8 ++++----
 codecs/lpc10/f2c.h    |  4 ++--
 codecs/lpc10/f2clib.c |  4 ++--
 codecs/lpc10/ham84.c  |  8 ++++----
 codecs/lpc10/hp100.c  |  8 ++++----
 codecs/lpc10/invert.c | 12 ++++++------
 codecs/lpc10/irc2pc.c | 12 ++++++------
 codecs/lpc10/ivfilt.c |  8 ++++----
 codecs/lpc10/lpcdec.c | 16 ++++++++--------
 codecs/lpc10/lpcenc.c | 12 ++++++------
 codecs/lpc10/lpcini.c | 16 ++++++++--------
 codecs/lpc10/lpfilt.c |  8 ++++----
 codecs/lpc10/median.c |  8 ++++----
 codecs/lpc10/mload.c  |  8 ++++----
 codecs/lpc10/onset.c  | 12 ++++++------
 codecs/lpc10/pitsyn.c | 12 ++++++------
 codecs/lpc10/preemp.c |  8 ++++----
 codecs/lpc10/prepro.c |  8 ++++----
 codecs/lpc10/random.c |  8 ++++----
 codecs/lpc10/rcchk.c  |  8 ++++----
 codecs/lpc10/synths.c | 16 ++++++++--------
 30 files changed, 156 insertions(+), 156 deletions(-)

diff --git a/codecs/lpc10/f2c.h b/codecs/lpc10/f2c.h
index 30fab1d70b..63065b28fa 100755
--- a/codecs/lpc10/f2c.h
+++ b/codecs/lpc10/f2c.h
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
diff --git a/codecs/lpc10/f2clib.c b/codecs/lpc10/f2clib.c
index 1045118b99..180d2e2e0e 100755
--- a/codecs/lpc10/f2clib.c
+++ b/codecs/lpc10/f2clib.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
diff --git a/codecs/lpc10/analys.c b/codecs/lpc10/analys.c
index 28f81877c1..7ffa81122b 100755
--- a/codecs/lpc10/analys.c
+++ b/codecs/lpc10/analys.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -79,8 +79,8 @@ static integer c__1 = 1;
 /* 	ANALYS Version 55 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -246,8 +246,8 @@ static integer c__1 = 1;
     real phi[100]	/* was [10][10] */, psi[10];
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -277,8 +277,8 @@ static integer c__1 = 1;
 /* Frame size, Prediction order, Pitch period */
 /*       Arguments to ANALYS */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -79,8 +79,8 @@ static integer c__1 = 1;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -246,8 +246,8 @@ static integer c__1 = 1;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -277,8 +277,8 @@ static integer c__1 = 1;
 /*       Arguments to ANALYS */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/bsynz.c b/codecs/lpc10/bsynz.c
index 89d6c0ede9..fe743124fe 100755
--- a/codecs/lpc10/bsynz.c
+++ b/codecs/lpc10/bsynz.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -48,8 +48,8 @@ extern struct {
 /* 	BSYNZ Version 54 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -144,8 +144,8 @@ extern struct {
     real lpi0, hpi0;
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -175,8 +175,8 @@ extern struct {
 /* Frame size, Prediction order, Pitch period */
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -48,8 +48,8 @@ extern struct {
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -144,8 +144,8 @@ extern struct {
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -175,8 +175,8 @@ extern struct {
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/chanwr.c b/codecs/lpc10/chanwr.c
index b24ecc7aa7..6ed6e944e7 100755
--- a/codecs/lpc10/chanwr.c
+++ b/codecs/lpc10/chanwr.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -35,8 +35,8 @@ extern int chanrd_(integer *order, integer *ipitv, integer *irms, integer *irc,
 /* 	CHANL Version 49 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -35,8 +35,8 @@ extern int chanrd_(integer *order, integer *ipitv, integer *irms, integer *irc,
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/dcbias.c b/codecs/lpc10/dcbias.c
index 3b0a49251a..790f737bb1 100755
--- a/codecs/lpc10/dcbias.c
+++ b/codecs/lpc10/dcbias.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int dcbias_(integer *len, real *speech, real *sigout);
 /* 	DCBIAS Version 50 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int dcbias_(integer *len, real *speech, real *sigout);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/decode.c b/codecs/lpc10/decode.c
index 4882c65324..af4f69886d 100755
--- a/codecs/lpc10/decode.c
+++ b/codecs/lpc10/decode.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -53,8 +53,8 @@ static integer c__2 = 2;
 /* 	DECODE Version 54 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -188,8 +188,8 @@ static integer c__2 = 2;
     integer ishift, errcnt, lsb;
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -219,8 +219,8 @@ static integer c__2 = 2;
 /* Frame size, Prediction order, Pitch period */
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -53,8 +53,8 @@ static integer c__2 = 2;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -188,8 +188,8 @@ static integer c__2 = 2;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -219,8 +219,8 @@ static integer c__2 = 2;
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/deemp.c b/codecs/lpc10/deemp.c
index c1fc3f52a1..9d91b306d7 100755
--- a/codecs/lpc10/deemp.c
+++ b/codecs/lpc10/deemp.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern int deemp_(real *x, integer *n, struct lpc10_decoder_state *st);
 /* 	DEEMP Version 48 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern int deemp_(real *x, integer *n, struct lpc10_decoder_state *st);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/difmag.c b/codecs/lpc10/difmag.c
index becfb79fab..328eda0621 100755
--- a/codecs/lpc10/difmag.c
+++ b/codecs/lpc10/difmag.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int difmag_(real *speech, integer *lpita, integer *tau, integer *ltau, in
 /* 	DIFMAG Version 49 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int difmag_(real *speech, integer *lpita, integer *tau, integer *ltau, in
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/dyptrk.c b/codecs/lpc10/dyptrk.c
index 9180c15a7b..429321f9a8 100755
--- a/codecs/lpc10/dyptrk.c
+++ b/codecs/lpc10/dyptrk.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -47,8 +47,8 @@ extern struct {
 /* 	DYPTRK Version 52 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -136,8 +136,8 @@ extern struct {
 
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -47,8 +47,8 @@ extern struct {
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -136,8 +136,8 @@ extern struct {
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/encode.c b/codecs/lpc10/encode.c
index b89402afff..ec7a1dfa16 100755
--- a/codecs/lpc10/encode.c
+++ b/codecs/lpc10/encode.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -43,8 +43,8 @@ static integer c__2 = 2;
 /* 	ENCODE Version 54 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -128,8 +128,8 @@ static integer c__2 = 2;
     integer idel, nbit, i__, j, i2, i3, mrk;
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -151,8 +151,8 @@ static integer c__2 = 2;
 /* Frame size, Prediction order, Pitch period */
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -43,8 +43,8 @@ static integer c__2 = 2;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -128,8 +128,8 @@ static integer c__2 = 2;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -151,8 +151,8 @@ static integer c__2 = 2;
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/energy.c b/codecs/lpc10/energy.c
index 43dfd0e518..01a736993a 100755
--- a/codecs/lpc10/energy.c
+++ b/codecs/lpc10/energy.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int energy_(integer *len, real *speech, real *rms);
 /* 	ENERGY Version 50 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int energy_(integer *len, real *speech, real *rms);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/ham84.c b/codecs/lpc10/ham84.c
index 2bf9922d68..84f87fae3d 100755
--- a/codecs/lpc10/ham84.c
+++ b/codecs/lpc10/ham84.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int ham84_(integer *input, integer *output, integer *errcnt);
 /* 	HAM84 Version 45G */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int ham84_(integer *input, integer *output, integer *errcnt);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/hp100.c b/codecs/lpc10/hp100.c
index 12df38f4ef..e4016f8687 100755
--- a/codecs/lpc10/hp100.c
+++ b/codecs/lpc10/hp100.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -39,8 +39,8 @@ extern int inithp100_(void);
 /*      HP100 Version 55 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -39,8 +39,8 @@ extern int inithp100_(void);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/invert.c b/codecs/lpc10/invert.c
index 8e7ce301b0..1c3212f001 100755
--- a/codecs/lpc10/invert.c
+++ b/codecs/lpc10/invert.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int invert_(integer *order, real *phi, real *psi, real *rc);
 /* 	INVERT Version 45G */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -91,8 +91,8 @@ extern int invert_(integer *order, real *phi, real *psi, real *rc);
 
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int invert_(integer *order, real *phi, real *psi, real *rc);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -91,8 +91,8 @@ extern int invert_(integer *order, real *phi, real *psi, real *rc);
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/irc2pc.c b/codecs/lpc10/irc2pc.c
index 7ba81ab9c3..ff533a0170 100755
--- a/codecs/lpc10/irc2pc.c
+++ b/codecs/lpc10/irc2pc.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int irc2pc_(real *rc, real *pc, integer *order, real *gprime, real *g2pas
 /* 	IRC2PC Version 48 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -82,8 +82,8 @@ extern int irc2pc_(real *rc, real *pc, integer *order, real *gprime, real *g2pas
 
 /* 	Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int irc2pc_(real *rc, real *pc, integer *order, real *gprime, real *g2pas
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -82,8 +82,8 @@ extern int irc2pc_(real *rc, real *pc, integer *order, real *gprime, real *g2pas
 /* 	Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/ivfilt.c b/codecs/lpc10/ivfilt.c
index 7b059732e8..1785a4677e 100755
--- a/codecs/lpc10/ivfilt.c
+++ b/codecs/lpc10/ivfilt.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int ivfilt_(real *lpbuf, real *ivbuf, integer *len, integer *nsamp, real
 /* 	IVFILT Version 48 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int ivfilt_(real *lpbuf, real *ivbuf, integer *len, integer *nsamp, real
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/lpcdec.c b/codecs/lpc10/lpcdec.c
index cf2f002d5a..e752ec9631 100755
--- a/codecs/lpc10/lpcdec.c
+++ b/codecs/lpc10/lpcdec.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -58,8 +58,8 @@ static integer c__10 = 10;
 /* ***************************************************************** */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -113,8 +113,8 @@ static integer c__10 = 10;
     real rms;
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -147,8 +147,8 @@ static integer c__10 = 10;
 /* Frame size, Prediction order, Pitch period */
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -58,8 +58,8 @@ static integer c__10 = 10;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -113,8 +113,8 @@ static integer c__10 = 10;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -147,8 +147,8 @@ static integer c__10 = 10;
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/lpcenc.c b/codecs/lpc10/lpcenc.c
index b786cdef9d..dfeb9a69b0 100755
--- a/codecs/lpc10/lpcenc.c
+++ b/codecs/lpc10/lpcenc.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -50,8 +50,8 @@ static integer c__10 = 10;
 /* ***************************************************************** */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -109,8 +109,8 @@ static integer c__10 = 10;
 
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -50,8 +50,8 @@ static integer c__10 = 10;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -109,8 +109,8 @@ static integer c__10 = 10;
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/lpcini.c b/codecs/lpc10/lpcini.c
index e73de1f61b..32c259c543 100755
--- a/codecs/lpc10/lpcini.c
+++ b/codecs/lpc10/lpcini.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -45,8 +45,8 @@ struct {
 /* ***************************************************************** */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -71,8 +71,8 @@ struct {
 {
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -97,8 +97,8 @@ struct {
 /*   LPC Configuration parameters: */
 /* Frame size, Prediction order, Pitch period */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -45,8 +45,8 @@ struct {
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -71,8 +71,8 @@ struct {
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -97,8 +97,8 @@ struct {
 /* Frame size, Prediction order, Pitch period */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/lpfilt.c b/codecs/lpc10/lpfilt.c
index b21727a438..4252c6820d 100755
--- a/codecs/lpc10/lpfilt.c
+++ b/codecs/lpc10/lpfilt.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int lpfilt_(real *inbuf, real *lpbuf, integer *len, integer *nsamp);
 /* 	LPFILT Version 55 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int lpfilt_(real *inbuf, real *lpbuf, integer *len, integer *nsamp);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/median.c b/codecs/lpc10/median.c
index 52e34b48cb..e63618f2ad 100755
--- a/codecs/lpc10/median.c
+++ b/codecs/lpc10/median.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern integer median_(integer *d1, integer *d2, integer *d3);
 /* 	MEDIAN Version 45G */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern integer median_(integer *d1, integer *d2, integer *d3);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/mload.c b/codecs/lpc10/mload.c
index 2fd9ee7f58..a4d15705b6 100755
--- a/codecs/lpc10/mload.c
+++ b/codecs/lpc10/mload.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int mload_(integer *order, integer *awins, integer *awinf, real *speech,
 /* 	MLOAD Version 48 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int mload_(integer *order, integer *awins, integer *awinf, real *speech,
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/onset.c b/codecs/lpc10/onset.c
index b66ee6cfcd..4f220a0444 100755
--- a/codecs/lpc10/onset.c
+++ b/codecs/lpc10/onset.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -41,8 +41,8 @@ static real c_b2 = 1.f;
 /* 	ONSET Version 49 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -143,8 +143,8 @@ static real c_b2 = 1.f;
 
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -41,8 +41,8 @@ static real c_b2 = 1.f;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -143,8 +143,8 @@ static real c_b2 = 1.f;
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/pitsyn.c b/codecs/lpc10/pitsyn.c
index 9f5bb79e67..292946c0ba 100755
--- a/codecs/lpc10/pitsyn.c
+++ b/codecs/lpc10/pitsyn.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern int pitsyn_(integer *order, integer *voice, integer *pitch, real *rms, re
 /* 	PITSYN Version 53 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -143,8 +143,8 @@ extern int pitsyn_(integer *order, integer *voice, integer *pitch, real *rms, re
 
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern int pitsyn_(integer *order, integer *voice, integer *pitch, real *rms, re
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -143,8 +143,8 @@ extern int pitsyn_(integer *order, integer *voice, integer *pitch, real *rms, re
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/preemp.c b/codecs/lpc10/preemp.c
index 3f31730cd9..19504955af 100755
--- a/codecs/lpc10/preemp.c
+++ b/codecs/lpc10/preemp.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int preemp_(real *inbuf, real *pebuf, integer *nsamp, real *coef, real *z
 /* 	PREEMP Version 55 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int preemp_(real *inbuf, real *pebuf, integer *nsamp, real *coef, real *z
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/prepro.c b/codecs/lpc10/prepro.c
index 485e3ed3b6..e1865ac86f 100755
--- a/codecs/lpc10/prepro.c
+++ b/codecs/lpc10/prepro.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -44,8 +44,8 @@ static integer c__1 = 1;
 /* 	PREPRO Version 48 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -44,8 +44,8 @@ static integer c__1 = 1;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/random.c b/codecs/lpc10/random.c
index 201a9e3b2d..70fb1a7b1e 100755
--- a/codecs/lpc10/random.c
+++ b/codecs/lpc10/random.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern integer random_(struct lpc10_decoder_state *st);
 /* 	RANDOM Version 49 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern integer random_(struct lpc10_decoder_state *st);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/rcchk.c b/codecs/lpc10/rcchk.c
index 95f2c50de4..69596b1774 100755
--- a/codecs/lpc10/rcchk.c
+++ b/codecs/lpc10/rcchk.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int rcchk_(integer *order, real *rc1f, real *rc2f);
 /* 	RCCHK Version 45G */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int rcchk_(integer *order, real *rc1f, real *rc2f);
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
diff --git a/codecs/lpc10/synths.c b/codecs/lpc10/synths.c
index 45f24a4f79..f6cb6e32e5 100755
--- a/codecs/lpc10/synths.c
+++ b/codecs/lpc10/synths.c
@@ -1,8 +1,8 @@
 /*
 
 $Log$
-Revision 1.8  2000/01/05 08:20:39  markster
-Version 0.1.9 from FTP
+Revision 1.9  2000/01/05 08:20:39  markster
+Version 0.1.10 from FTP
 
 Revision 1.2  2000/01/05 08:20:39  markster
 Some OSS fixes and a few lpc changes to make it actually work
@@ -58,8 +58,8 @@ static real c_b2 = .7f;
 /* 	SYNTHS Version 54 */
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -178,8 +178,8 @@ static real c_b2 = .7f;
     real rci[160]	/* was [10][16] */;
 
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -209,8 +209,8 @@ static real c_b2 = .7f;
 /* Frame size, Prediction order, Pitch period */
 /*       Arguments */
 /* $Log$
  * Revision 1.8  2000/01/05 08:20:39  markster
  * Version 0.1.9 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
 /* Some OSS fixes and a few lpc changes to make it actually work
@@ -58,8 +58,8 @@ static real c_b2 = .7f;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -178,8 +178,8 @@ static real c_b2 = .7f;
 
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
@@ -209,8 +209,8 @@ static real c_b2 = .7f;
 /*       Arguments */
 /* $Log$
- * Revision 1.8  2000/01/05 08:20:39  markster
- * Version 0.1.9 from FTP
+ * Revision 1.9  2000/01/05 08:20:39  markster
+ * Version 0.1.10 from FTP
  *
 /* Revision 1.2  2000/01/05 08:20:39  markster
-- 
GitLab